/*
**  IMAPStore.h
**
**  Copyright (c) 2001, 2002
**
**  Author: Ludovic Marcotte <ludovic@Sophos.ca>
**
**  This library is free software; you can redistribute it and/or
**  modify it under the terms of the GNU Lesser General Public
**  License as published by the Free Software Foundation; either
**  version 2.1 of the License, or (at your option) any later version.
**  
**  This library is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
**  Lesser General Public License for more details.
**  
**  You should have received a copy of the GNU Lesser General Public
**  License along with this library; if not, write to the Free Software
**  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*/

#import <Foundation/Foundation.h>

#import <Pantomime/Connection.h>
#import <Pantomime/Service.h>
#import <Pantomime/Store.h>

@class IMAPCacheManager;
@class IMAPFolder;
@class TCPConnection;

@interface IMAPStore : NSObject <Service, Store>
{
  NSString *name, *folderSeparator;
  int port, tag;

  id<Connection> tcpConnection;

  BOOL messagesHaveBeenPrefetched;

  NSMutableDictionary *openedFolders;

  NSString *username;
}

- (IMAPFolder *) folderForName: (NSString *) theName
                      prefetch: (BOOL) aBOOL;

- (IMAPFolder *) folderForName: (NSString *) theName
                        select: (BOOL) aBOOL;

- (IMAPFolder *) folderForName: (NSString *) theName
          withIMAPCacheManager: (IMAPCacheManager *) theIMAPCacheManager;

- (NSString *) nextTag;
- (NSString *) lastTag;


- (BOOL) subscribeToFolderWithName: (NSString *) theName;
- (BOOL) unsubscribeToFolderWithName: (NSString *) theName;


//
// Other methods
//
- (int) parseExists: (NSString *) theLine;
- (int) parseUIDValidity: (NSString *) theLine;

@end


//
// Private methods
//
@interface IMAPStore (Private)

- (void) _preInit;

@end
