/*
**  SMTP.h
**
**  Copyright (c) 2001, 2002
**
**  Author: Ludovic Marcotte <ludovic@Sophos.ca>
**
**  This library is free software; you can redistribute it and/or
**  modify it under the terms of the GNU Lesser General Public
**  License as published by the Free Software Foundation; either
**  version 2.1 of the License, or (at your option) any later version.
**  
**  This library is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
**  Lesser General Public License for more details.
**  
**  You should have received a copy of the GNU Lesser General Public
**  License along with this library; if not, write to the Free Software
**  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*/

#import <Foundation/Foundation.h>

#import <Pantomime/Connection.h>
#import <Pantomime/Service.h>
#import <Pantomime/Transport.h>

@class Message;
@class TCPConnection;
@class SMTPResponseLines;

//
//
//
@interface SMTP : NSObject <Service, Transport>
{
  id<Connection> tcpConnection;
  
  NSMutableArray *supportedAuthenticationMechanisms;

  NSString *name;
  int port;

  NSString *username;

  unsigned int maxSizeAllowedByServer; // rfc1870: Message Size Declaration
}

- (BOOL) authenticateWithUsername: (NSString *) theUsername
                         password: (NSString *) thePassword
                        mechanism: (NSString *) theMechanism;

- (void) close;

- (NSArray *) supportedAuthenticationMechanisms;

@end


//
// Private methods
//
@interface SMTP (Private)

- (void) _decodeSupportedAuthenticationMechanismFromString: (NSString *) theString;

- (void) _decodeMaxSizeAllowedFromString: (NSString *) theString;

- (BOOL) _responseFromServerIsEqualToCode: (NSString *) theCode;

- (BOOL) _responseFromServerIsEqualToCode: (NSString *) theCode
                           saveResponseIn: (SMTPResponseLines *) aSmtpResponse;

- (BOOL) _sendMessage: (Message *) theMessage
        withRawSource: (NSData *) theRawSource;

- (BOOL) _writeRecipients: (NSArray *) recipients
        usingBouncingMode: (BOOL) aBOOL;

- (BOOL) _writeMessageFromRawSource: (NSData *) theRawSource;

- (BOOL) _plainAuthenticationUsingUsername: (NSString *) theUsername
                                  password: (NSString *) thePassword;

- (BOOL) _loginAuthenticationUsingUsername: (NSString *) theUsername
                                  password: (NSString *) thePassword;

- (BOOL) _cramMD5AuthenticationUsingUsername: (NSString *) theUsername
                                    password: (NSString *) thePassword;

@end


//
//
//
@interface SMTPResponseLines : NSObject
{
  NSMutableArray *lines;
}

- (void) addLine: (NSString *) theLine;

- (unsigned int) count;

- (NSString *) lineAtIndex: (unsigned int) theIndex;

@end
